@@ -180,7 +180,7 @@ _opts = [
                       'For each network a section/group needs to be added to '
                       'the configuration file with these parameters set: '
                       'cidr, dhcp_start, dhcp_end, inspection_iprange, '
-                      'gateway and masquerade_network.'
+                      'gateway and masquerade.'
                       '\n\n'
                       'Example:\n\n'
                       'subnets = subnet1,subnet2\n'
@@ -193,7 +193,7 @@ _opts = [
                       'dhcp_end = 192.168.10.200\n'
                       'inspection_iprange = 192.168.10.20,192.168.10.90\n'
                       'gateway = 192.168.10.254\n'
-                      'masquerade_network = True'
+                      'masquerade = True'
                       '\n'
                       '[subnet2]\n'
                       '. . .\n')),
@@ -967,6 +967,14 @@ def _generate_endpoints(instack_env):
             '%s://%s:%d/v2.1',
             {'host': public_host, 'port': 8774, 'ssl_port': 13774},
             {'host': internal_host, 'port': 8774}),
+        ('nova-ui-proxy',
+            '%s://%s:%d',
+            {'host': public_host, 'port': 8774, 'ssl_port': 13774},
+            {'host': internal_host, 'port': 8774}),
+        ('nova-ui-config',
+            '%s://%s:%d/nova/v2.1',
+            {'host': public_host, 'port': 3000, 'ssl_port': 443},
+            {'host': internal_host, 'port': 3000}),
         ('placement',
             '%s://%s:%d/placement',
             {'host': public_host, 'port': 8778, 'ssl_port': 13778},
@@ -2187,11 +2195,9 @@ def _config_neutron_segments_and_subnets(sdk, ctlplane_id):
             s = CONF.get(name)
 
             phynet = name
+            metadata_nexthop = s.gateway
             if name == CONF.local_subnet:
                 phynet = PHYSICAL_NETWORK
-
-            metadata_nexthop = s.gateway
-            if str(netaddr.IPNetwork(CONF.local_ip).ip) in s.cidr:
                 metadata_nexthop = str(netaddr.IPNetwork(CONF.local_ip).ip)
 
             host_routes = [{'destination': '169.254.169.254/32',
